# frozen_string_literal: true

class Page < Document
end
